@@ -110,7 +110,7 @@ class HMACKey(Key):
             b'ssh-rsa'
         ]
 
-        if any([string_value in key for string_value in invalid_strings]):
+        if any(string_value in key for string_value in invalid_strings):
             raise JWKError(
                 'The specified key is an asymmetric key or x509 certificate and'
                 ' should not be used as an HMAC secret.')
